@@ -38,11 +38,11 @@ import ghidra.app.plugin.core.debug.service.platform.DebuggerPlatformServicePlug
 import ghidra.app.services.DebuggerEmulationService.EmulationResult;
 import ghidra.app.services.DebuggerStaticMappingService;
 import ghidra.app.services.DebuggerTraceManagerService.ActivationCause;
-import ghidra.debug.api.emulation.DebuggerPcodeMachine;
 import ghidra.debug.api.platform.DebuggerPlatformMapper;
 import ghidra.debug.api.tracemgr.DebuggerCoordinates;
-import ghidra.pcode.emu.PcodeThread;
+import ghidra.pcode.emu.*;
 import ghidra.pcode.exec.*;
+import ghidra.pcode.exec.trace.TraceEmulationIntegration.Writer;
 import ghidra.pcode.utils.Utils;
 import ghidra.program.model.address.Address;
 import ghidra.program.model.address.AddressSpace;
@@ -52,16 +52,18 @@ import ghidra.program.model.listing.ProgramContext;
 import ghidra.program.model.mem.Memory;
 import ghidra.program.model.mem.MemoryBlock;
 import ghidra.program.util.ProgramLocation;
+import ghidra.trace.database.ToyDBTraceBuilder.ToySchemaBuilder;
 import ghidra.trace.model.*;
-import ghidra.trace.model.breakpoint.TraceBreakpoint;
 import ghidra.trace.model.breakpoint.TraceBreakpointKind;
+import ghidra.trace.model.breakpoint.TraceBreakpointLocation;
 import ghidra.trace.model.guest.TracePlatform;
 import ghidra.trace.model.memory.TraceMemoryManager;
 import ghidra.trace.model.memory.TraceMemorySpace;
-import ghidra.trace.model.stack.TraceObjectStack;
-import ghidra.trace.model.stack.TraceObjectStackFrame;
+import ghidra.trace.model.stack.TraceStack;
+import ghidra.trace.model.stack.TraceStackFrame;
 import ghidra.trace.model.target.path.KeyPath;
 import ghidra.trace.model.target.path.PathFilter;
+import ghidra.trace.model.target.schema.SchemaContext;
 import ghidra.trace.model.target.schema.TraceObjectSchema;
 import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.model.time.TraceSnapshot;
@@ -249,6 +251,13 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 			mem.getViewValue(scratch, regW1).getUnsignedValue());
 	}
 
+	protected SchemaContext buildContext() {
+		return new ToySchemaBuilder()
+				.noRegisterGroups()
+				.useRegistersPerFrame()
+				.build();
+	}
+
 	@Test
 	public void testPureEmulationRelocated() throws Throwable {
 		createAndOpenTrace("x86:LE:64:default");
@@ -282,7 +291,9 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		TraceThread thread;
 		TraceMemorySpace regs;
 		try (Transaction tx = tb.startTransaction()) {
+			tb.createRootObject(buildContext(), "Target");
 			thread = tb.getOrAddThread("Threads[0]", 0);
+			tb.createObjectsFramesAndRegs(thread, Lifespan.nowOn(0), tb.host, 1);
 			regs = tb.trace.getMemoryManager().getMemoryRegisterSpace(thread, true);
 			regs.setValue(0, new RegisterValue(program.getLanguage().getProgramCounter(),
 				BigInteger.valueOf(0x55550000)));
@@ -295,8 +306,8 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		waitForSwing();
 		waitOn(settled);
 
-		long scratch =
-			emulationPlugin.emulate(tb.trace, TraceSchedule.parse("0:t0-1"), TaskMonitor.DUMMY);
+		long scratch = emulationPlugin.emulate(tb.trace,
+			TraceSchedule.parse("0:t%d-1".formatted(thread.getKey())), TaskMonitor.DUMMY);
 
 		assertEquals("deadbeefcafebabe",
 			regs.getViewValue(scratch, tb.reg("RAX")).getUnsignedValue().toString(16));
@@ -315,7 +326,9 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		TraceMemoryManager mem = tb.trace.getMemoryManager();
 		TraceThread thread;
 		try (Transaction tx = tb.startTransaction()) {
+			tb.createRootObject(buildContext(), "Target");
 			thread = tb.getOrAddThread("Threads[0]", 0);
+			tb.createObjectsFramesAndRegs(thread, Lifespan.nowOn(0), tb.host, 1);
 			buf.assemble("MOV RAX, qword ptr [0x00600800]");
 			mem.putBytes(0, tb.addr(0x00400000), ByteBuffer.wrap(buf.getBytes()));
 			mem.putBytes(0, tb.addr(0x00600800),
@@ -334,7 +347,7 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 					.findAny()
 					.orElse(null)
 					.take(tool, tb.trace);
-		platformPlugin.setCurrentMapperFor(tb.trace, mapper, 0);
+		platformPlugin.setCurrentMapperFor(tb.trace, null, mapper, 0);
 		waitForSwing();
 
 		waitForPass(() -> assertEquals(x64, traceManager.getCurrentPlatform().getLanguage()));
@@ -344,8 +357,8 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 			tb.exec(platform, 0, thread, 0, "RIP = 0x00400000;");
 		}
 
-		long scratch =
-			emulationPlugin.emulate(platform, TraceSchedule.parse("0:t0-1"), TaskMonitor.DUMMY);
+		long scratch = emulationPlugin.emulate(platform,
+			TraceSchedule.parse("0:t%d-1".formatted(thread.getKey())), TaskMonitor.DUMMY);
 		TraceMemorySpace regs = mem.getMemoryRegisterSpace(thread, false);
 		assertEquals("deadbeefcafebabe",
 			regs.getViewValue(platform, scratch, tb.reg(platform, "RAX"))
@@ -494,11 +507,11 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 			trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), addrText, Set.of(thread),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "test");
-			TraceBreakpoint tb = trace.getBreakpointManager()
+			TraceBreakpointLocation tb = trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[1]", Lifespan.nowOn(0), addrI1, Set.of(thread),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "test");
 			// Force "partial instruction"
-			tb.setEmuSleigh("""
+			tb.setEmuSleigh(0, """
 					r1 = 0xbeef;
 					emu_swi();
 					emu_exec_decoded();
@@ -520,7 +533,7 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		assertTrue(result1.error() instanceof InterruptPcodeExecutionException);
 
 		// Save this for comparison later
-		DebuggerPcodeMachine<?> emu = Unique.assertOne(emulationPlugin.cache.values()).emulator();
+		PcodeMachine<?> emu = Unique.assertOne(emulationPlugin.cache.values()).emulator();
 
 		// This will test if the one just hit gets ignored
 		EmulationResult result2 = emulationPlugin.run(trace.getPlatformManager().getHostPlatform(),
@@ -568,11 +581,11 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 			trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), addrText, Set.of(thread),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "test");
-			TraceBreakpoint tb = trace.getBreakpointManager()
+			TraceBreakpointLocation tb = trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[1]", Lifespan.nowOn(0), addrI1, Set.of(thread),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "test");
 			// Force "partial instruction"
-			tb.setEmuSleigh("""
+			tb.setEmuSleigh(0, """
 					r1 = 0xbeef;
 					emu_swi();
 					emu_exec_decoded();
@@ -591,7 +604,7 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		assertTrue(result1.error() instanceof InterruptPcodeExecutionException);
 
 		// Save this for comparison later
-		DebuggerPcodeMachine<?> emu = Unique.assertOne(emulationPlugin.cache.values()).emulator();
+		PcodeMachine<?> emu = Unique.assertOne(emulationPlugin.cache.values()).emulator();
 
 		// Now, step it forward to complete the instruction
 		emulationPlugin.emulate(trace.getPlatformManager().getHostPlatform(),
@@ -634,11 +647,11 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		TraceThread thread = Unique.assertOne(trace.getThreadManager().getAllThreads());
 
 		try (Transaction tx = trace.openTransaction("Add breakpoint")) {
-			TraceBreakpoint tb = trace.getBreakpointManager()
+			TraceBreakpointLocation tb = trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[1]", Lifespan.nowOn(0), addrI1, Set.of(thread),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "test");
 			// Force "partial instruction"
-			tb.setEmuSleigh("""
+			tb.setEmuSleigh(0, """
 					r1 = 0xbeef;
 					pcodeop_one(r1);
 					emu_exec_decoded();
@@ -658,7 +671,7 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		assertTrue(result1.error() instanceof PcodeExecutionException);
 
 		// Save this for comparison later
-		DebuggerPcodeMachine<?> emu = Unique.assertOne(emulationPlugin.cache.values()).emulator();
+		PcodeMachine<?> emu = Unique.assertOne(emulationPlugin.cache.values()).emulator();
 
 		// We shouldn't get any further
 		EmulationResult result2 = emulationPlugin.run(trace.getPlatformManager().getHostPlatform(),
@@ -709,10 +722,10 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 		TraceMemorySpace regs = trace.getMemoryManager().getMemoryRegisterSpace(thread, false);
 
 		try (Transaction tx = trace.openTransaction("Add breakpoint")) {
-			TraceBreakpoint tb = trace.getBreakpointManager()
+			TraceBreakpointLocation tb = trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), addrI2, Set.of(thread),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "test");
-			tb.setEmuSleigh("""
+			tb.setEmuSleigh(0, """
 					r1 = 0x5678;
 					emu_swi();
 					emu_exec_decoded();
@@ -854,10 +867,10 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 
 		// Inject some logic that would require a cache refresh to materialize
 		try (Transaction tx = trace.openTransaction("Add breakpoint")) {
-			TraceBreakpoint tb = trace.getBreakpointManager()
+			TraceBreakpointLocation tb = trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), addrI2, Set.of(thread),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "test");
-			tb.setEmuSleigh("""
+			tb.setEmuSleigh(0, """
 					r1 = 0x5678;
 					emu_exec_decoded();
 					""");
@@ -966,16 +979,17 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 			TracePlatform host = tb.trace.getPlatformManager().getHostPlatform();
 			DefaultPcodeDebuggerAccess access =
 				new DefaultPcodeDebuggerAccess(tool, null, host, restartEmuSnap);
-			BytesDebuggerPcodeEmulator emulator = new BytesDebuggerPcodeEmulator(access);
+			Writer writer = DebuggerEmulationIntegration.bytesDelayedWriteTrace(access);
+			PcodeEmulator emulator = new PcodeEmulator(access.getLanguage(), writer.callbacks());
 
 			TraceSnapshot snapshot =
 				tb.trace.getTimeManager().createSnapshot("created new emulator thread");
 			long newSnap = snapshot.getKey();
-			emulator.writeDown(host, newSnap, newSnap);
+			writer.writeDown(newSnap);
 
 			TraceThread newTraceThread = ProgramEmulationUtils.doLaunchEmulationThread(tb.trace,
 				newSnap, program, tb.addr(0x00400000), addr(program, 0x00400000));
-			newTraceThread.setName("MyThread");
+			newTraceThread.setName(newSnap, "MyThread");
 
 			@SuppressWarnings("unused")
 			PcodeThread<byte[]> newEmuThread = emulator.newThread(newTraceThread.getPath());
@@ -986,10 +1000,10 @@ public class DebuggerEmulationServiceTest extends AbstractGhidraHeadedDebuggerTe
 	public void testEmuSchemaHasWorkingStackFrames() throws Exception {
 		TraceObjectSchema rootSchema = ProgramEmulationUtils.EMU_SESSION_SCHEMA;
 		TraceObjectSchema threadSchema = rootSchema.getSuccessorSchema(KeyPath.parse("Threads[1]"));
-		KeyPath found = threadSchema.searchForCanonicalContainer(TraceObjectStackFrame.class);
+		KeyPath found = threadSchema.searchForCanonicalContainer(TraceStackFrame.class);
 		assertEquals(KeyPath.parse("Stack"), found);
 
-		PathFilter stackFilter = threadSchema.searchFor(TraceObjectStack.class, false);
+		PathFilter stackFilter = threadSchema.searchFor(TraceStack.class, false);
 		assertNotNull("Non-unique Stack", stackFilter.getSingletonPath());
 	}
 }
