@@ -595,7 +595,7 @@ public class CodeBrowserOptionsTest extends AbstractGhidraHeadedIntegrationTest
 
 		cb.goToField(callAddress, "Bytes", 0, 0);
 
-		SetCommentCmd eolCmd = new SetCommentCmd(callAddress, CodeUnit.EOL_COMMENT,
+		SetCommentCmd eolCmd = new SetCommentCmd(callAddress, CommentType.EOL,
 			"a bb ccc dddd eeeee ffff ggg hhh ii j k ll mmm nnn oooo " +
 				"ppppp qqqq rrrr ssss tttt uuuuu vvvvvv wwwww\n\n\n\n" +
 				"AAA BBB CCC DDD EEE FFF GGG HHH III JJJ KKK LLL MMM NNN OOO PPP QQQ " +
@@ -604,7 +604,7 @@ public class CodeBrowserOptionsTest extends AbstractGhidraHeadedIntegrationTest
 				"4444 55555 666666 7777777 88888888 999999999 0000000000 1 22 333 4444 55555");
 		tool.execute(eolCmd, program);
 
-		SetCommentCmd repeatCmd = new SetCommentCmd(callAddress, CodeUnit.REPEATABLE_COMMENT,
+		SetCommentCmd repeatCmd = new SetCommentCmd(callAddress, CommentType.REPEATABLE,
 			"Local repeatable line1.\n" + "\n" + "Line3 of repeatable.");
 		tool.execute(repeatCmd, program);
 
@@ -613,7 +613,7 @@ public class CodeBrowserOptionsTest extends AbstractGhidraHeadedIntegrationTest
 			new CreateFunctionCmd(null, callRefAddress, body, SourceType.USER_DEFINED);
 		tool.execute(createFunctionCmd, program);
 
-		SetCommentCmd callRepeatCmd = new SetCommentCmd(callRefAddress, CodeUnit.REPEATABLE_COMMENT,
+		SetCommentCmd callRepeatCmd = new SetCommentCmd(callRefAddress, CommentType.REPEATABLE,
 			"\n" + "Function Repeatable line2");
 		tool.execute(callRepeatCmd, program);
 
@@ -621,8 +621,8 @@ public class CodeBrowserOptionsTest extends AbstractGhidraHeadedIntegrationTest
 			SourceType.USER_DEFINED, 0, false);
 		tool.execute(addRefCmd, program);
 
-		SetCommentCmd commentRefCmd = new SetCommentCmd(otherRefAddress,
-			CodeUnit.REPEATABLE_COMMENT, "Mem ref line1.\n" + "");
+		SetCommentCmd commentRefCmd =
+			new SetCommentCmd(otherRefAddress, CommentType.REPEATABLE, "Mem ref line1.\n" + "");
 		tool.execute(commentRefCmd, program);
 
 		// these values are all DEFAULT, by default; set them in case that changes in the future
@@ -692,16 +692,16 @@ public class CodeBrowserOptionsTest extends AbstractGhidraHeadedIntegrationTest
 		options.setBoolean(WORD_WRAP, false);
 		cb.updateNow();
 		btf = (ListingTextField) cb.getCurrentField();
-		assertEquals(12, getNumberOfLines(btf));
+		assertEquals(11, getNumberOfLines(btf));
 		assertTrue("; ".equals(btf.getFieldElement(5, 0).getText()));
 
 		options.setBoolean(SHOW_SEMICOLON, false);
 		cb.updateNow();
 		btf = (ListingTextField) cb.getCurrentField();
-		assertEquals(12, getNumberOfLines(btf));
-		assertFalse("; ".equals(btf.getFieldElement(1, 0).getText()));
-		assertEquals("01003fa1", btf.getFieldElement(11, 4).getText());
-		assertEquals("Mem ref line1.", btf.getFieldElement(11, 11).getText());
+		assertEquals(11, getNumberOfLines(btf));
+		assertTrue("".equals(btf.getFieldElement(1, 0).getText())); // blank line - leading ';' not present
+		assertEquals("01003fa1", btf.getFieldElement(9, 4).getText());
+		assertEquals("Mem ref line1.", btf.getFieldElement(9, 11).getText());
 
 		options.setBoolean(SHOW_REF_ADDR, false);
 		cb.updateNow();
@@ -789,8 +789,8 @@ public class CodeBrowserOptionsTest extends AbstractGhidraHeadedIntegrationTest
 
 		//--- Verify register variable markup options
 
-		Command cmd = new AddRegisterRefCmd(addr("0x1002d0b"), 0, program.getRegister("EDI"),
-			SourceType.USER_DEFINED);
+		Command<Program> cmd = new AddRegisterRefCmd(addr("0x1002d0b"), 0,
+			program.getRegister("EDI"), SourceType.USER_DEFINED);
 		applyCmd(program, cmd);
 		cb.updateNow();
 
