@@ -18,7 +18,7 @@ package agent.lldb.rmi;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.*;
 import static org.junit.Assert.*;
-import static org.junit.Assume.assumeTrue;
+import static org.junit.Assume.*;
 
 import java.util.*;
 
@@ -54,8 +54,9 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 		try (LldbAndConnection conn = startAndConnectLldb()) {
 			RemoteMethod execute = conn.getMethod("execute");
 			assertEquals(false, execute.parameters().get("to_string").getDefaultValue());
-			assertEquals("test\n",
-				execute.invoke(Map.of("cmd", "script print('test')", "to_string", true)));
+			String result =
+				(String) execute.invoke(Map.of("cmd", "script print('test')", "to_string", true));
+			assertEquals("test\n", result.replace("\r\n", "\n"));
 			conn.success();
 		}
 	}
@@ -67,7 +68,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			conn.execute("kill");
 			conn.success();
 		}
-		try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+		try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 			// Just confirm it's present
 		}
 	}
@@ -104,7 +105,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "breakpoints");
 
 			RemoteMethod refreshProcBreakpoints = conn.getMethod("refresh_proc_breakpoints");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -143,7 +144,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "all");
 
 			RemoteMethod refreshProcWatchpoints = conn.getMethod("refresh_proc_watchpoints");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -219,7 +220,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "all");
 
 			RemoteMethod refreshEnvironment = conn.getMethod("refresh_environment");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				TraceObject env = Objects.requireNonNull(tb.objAny0(path));
 
@@ -242,7 +243,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txCreate(conn, path);
 
 			RemoteMethod refreshThreads = conn.getMethod("refresh_threads");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				TraceObject threads = Objects.requireNonNull(tb.objAny0(path));
 
@@ -262,10 +263,10 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			conn.execute("file " + getSpecimenPrint());
 			conn.execute("ghidra trace start");
 			txPut(conn, "processes");
-			breakAt(conn, "puts");
+			breakAt(conn, "wrapputs");
 
 			RemoteMethod refreshStack = conn.getMethod("refresh_stack");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				waitTxDone();
@@ -296,7 +297,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			conn.execute("ghidra trace tx-commit");
 
 			RemoteMethod refreshRegisters = conn.getMethod("refresh_registers");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				conn.execute("expr $%s = 0xdeadbeef".formatted(PLAT.intReg()));
@@ -324,7 +325,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txCreate(conn, path);
 
 			RemoteMethod refreshMappings = conn.getMethod("refresh_mappings");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				TraceObject memory = Objects.requireNonNull(tb.objAny0(path));
 
@@ -347,7 +348,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txCreate(conn, path);
 
 			RemoteMethod refreshModules = conn.getMethod("refresh_modules");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				TraceObject modules = Objects.requireNonNull(tb.objAny0(path));
 
@@ -366,17 +367,18 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 	@Test
 	public void testActivateThread() throws Exception {
 		// This test crashes lldb-1500.0.404.7 on macOS arm64
-		assumeTrue(OperatingSystem.CURRENT_OPERATING_SYSTEM == OperatingSystem.LINUX);
+		OperatingSystem os = OperatingSystem.CURRENT_OPERATING_SYSTEM;
+		assumeTrue(os == OperatingSystem.LINUX || os == OperatingSystem.WINDOWS);
 		try (LldbAndConnection conn = startAndConnectLldb()) {
 			// TODO:  need to find this file (same issue in LldbHookTests
-			String dproc = DummyProc.which("expCloneExit");
-			conn.execute("file " + dproc);
+			conn.execute("file " + getSpecimenNewThreadAndExit());
 			conn.execute("ghidra trace start");
 			txPut(conn, "processes");
 			breakAt(conn, "work");
 
 			RemoteMethod activateThread = conn.getMethod("activate_thread");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expCloneExit")) {
+			try (ManagedDomainObject mdo = openDomainObject(
+				IS_WINDOWS ? projectName("expCreateThreadExit") : projectName("expCloneExit"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				waitTxDone();
@@ -389,7 +391,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 						.getValuePaths(Lifespan.at(0), pattern)
 						.map(p -> p.getDestination(null))
 						.toList();
-				assertEquals(2, list.size());
+				assertTrue(list.size() > getSleepThreadCount());
 
 				for (TraceObject t : list) {
 					activateThread.invoke(Map.of("thread", t));
@@ -398,7 +400,8 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 					long index = Long.decode(indices.get(1));
 					assertThat(out, Matchers
 							.either(containsString("tid = %s".formatted(index)))
-							.or(containsString("tid = 0x%x".formatted(index))));
+							.or(containsString("tid = 0x%x".formatted(index)))
+							.or(containsString("tid = 0x0%x".formatted(index))));
 				}
 			}
 			conn.success();
@@ -411,10 +414,10 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			conn.execute("file " + getSpecimenPrint());
 			conn.execute("ghidra trace start");
 			txPut(conn, "processes");
-			breakAt(conn, "puts");
+			breakAt(conn, "wrapputs");
 
 			RemoteMethod activateFrame = conn.getMethod("activate_frame");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				waitTxDone();
@@ -446,7 +449,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod removeProcess = conn.getMethod("remove_process");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				TraceObject proc2 = Objects.requireNonNull(tb.objAny0("Processes[]"));
@@ -520,7 +523,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			//conn.execute("process attach -p %d".formatted(dproc.pid));
 
 			RemoteMethod detach = conn.getMethod("detach");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				TraceObject proc = Objects.requireNonNull(tb.objAny0("Processes[]"));
@@ -551,7 +554,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 				waitStopped(conn);
 
 				String out = conn.executeCapture("target list");
-				assertThat(out, containsString(getSpecimenPrint()));
+				assertThat(out, containsString(DummyProc.which("expPrint")));
 			}
 			conn.success();
 		}
@@ -596,7 +599,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod kill = conn.getMethod("kill");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -651,7 +654,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod step_into = conn.getMethod("step_into");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				waitTxDone();
@@ -681,7 +684,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod step_over = conn.getMethod("step_over");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				txPut(conn, "threads");
@@ -711,7 +714,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod step_advance = conn.getMethod("step_advance");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				txPut(conn, "threads");
@@ -737,14 +740,16 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 	@Test
 	public void testFinish() throws Exception {
 		try (LldbAndConnection conn = startAndConnectLldb()) {
-			conn.execute("file " + getSpecimenPrint());
+			// NB: These examples have shorter per-platform "step out"'s
+			conn.execute("file " + (IS_WINDOWS ? getSpecimenRead() : getSpecimenPrint()));
 			conn.execute("ghidra trace start");
 			txPut(conn, "processes");
-			breakAt(conn, "puts");
+			breakAt(conn, IS_WINDOWS ? "wrapread" : "wrapputs");
 
 			RemoteMethod activate = conn.getMethod("activate_thread");
 			RemoteMethod step_out = conn.getMethod("step_out");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo =
+				openDomainObject(projectName(IS_WINDOWS ? "expRead" : "expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				waitTxDone();
@@ -757,6 +762,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 				int initDepth = getDepth(conn);
 
 				step_out.invoke(Map.of("thread", thread));
+				waitStopped(conn);
 
 				int finalDepth = getDepth(conn);
 				assertEquals(initDepth - 1, finalDepth);
@@ -771,11 +777,11 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			conn.execute("file " + getSpecimenPrint());
 			conn.execute("ghidra trace start");
 			txPut(conn, "processes");
-			breakAt(conn, "puts");
+			breakAt(conn, "wrapputs");
 
 			RemoteMethod activate = conn.getMethod("activate_thread");
 			RemoteMethod ret = conn.getMethod("step_return");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 				waitTxDone();
@@ -803,7 +809,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakAddress = conn.getMethod("break_address");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				TraceObject proc = Objects.requireNonNull(tb.objAny0("Processes[]"));
@@ -825,7 +831,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakExpression = conn.getMethod("break_expression");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -846,7 +852,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakAddress = conn.getMethod("break_hw_address");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -868,7 +874,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakExpression = conn.getMethod("break_hw_expression");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -890,7 +896,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakRange = conn.getMethod("break_read_range");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -917,7 +923,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakExpression = conn.getMethod("break_read_expression");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				breakExpression.invoke(Map.of(
@@ -940,7 +946,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakRange = conn.getMethod("break_write_range");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -969,7 +975,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakExpression = conn.getMethod("break_write_expression");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				breakExpression.invoke(Map.of(
@@ -994,7 +1000,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakRange = conn.getMethod("break_access_range");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -1021,7 +1027,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakExpression = conn.getMethod("break_access_expression");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				breakExpression.invoke(Map.of(
@@ -1045,7 +1051,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod breakExc = conn.getMethod("break_exception");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				breakExc.invoke(Map.of("lang", "C++"));
@@ -1065,7 +1071,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod toggleBreakpoint = conn.getMethod("toggle_breakpoint");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -1089,7 +1095,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod toggleBreakpointLocation = conn.getMethod("toggle_breakpoint_location");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -1114,7 +1120,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 			txPut(conn, "processes");
 
 			RemoteMethod deleteBreakpoint = conn.getMethod("delete_breakpoint");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 				waitStopped(conn);
 
@@ -1139,7 +1145,7 @@ public class LldbMethodsTest extends AbstractLldbTraceRmiTest {
 
 			RemoteMethod breakExpression = conn.getMethod("break_read_expression");
 			RemoteMethod deleteWatchpoint = conn.getMethod("delete_watchpoint");
-			try (ManagedDomainObject mdo = openDomainObject("/New Traces/lldb/expPrint")) {
+			try (ManagedDomainObject mdo = openDomainObject(projectName("expPrint"))) {
 				tb = new ToyDBTraceBuilder((Trace) mdo.get());
 
 				breakExpression.invoke(Map.of(
